@@ -23,7 +23,7 @@ __copyright__ = '(C) 2015, Pedro Venancio'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
 
 import os
 
@@ -31,6 +31,7 @@ from qgis.PyQt.QtGui import QIcon
 
 from qgis.core import (QgsMapLayer,
                        QgsProcessing,
+                       QgsProcessingAlgorithm,
                        QgsProcessingException,
                        QgsProcessingParameterCrs,
                        QgsProcessingParameterEnum,
@@ -106,7 +107,7 @@ class gdaltindex(GdalAlgorithm):
         return 'tileindex'
 
     def displayName(self):
-        return self.tr('Tile Index')
+        return self.tr('Tile index')
 
     def group(self):
         return self.tr('Raster miscellaneous')
@@ -150,7 +151,7 @@ class gdaltindex(GdalAlgorithm):
             arguments.append('-src_srs_name {}'.format(crs_field))
 
         if crs_format:
-            arguments.append('-src_srs_format {}'.format(self.modes[crs_format][1]))
+            arguments.append('-src_srs_format {}'.format(self.formats[crs_format][1]))
 
         if target_crs.isValid():
             arguments.append('-t_srs')
