@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
 
 from .i import verifyRasterNum
 
@@ -36,4 +36,4 @@ def checkParameterValuesBeforeExecuting(alg, parameters, context):
     elif (alg.parameterAsBool(parameters, '-l', context)
           or alg.parameterAsBool(parameters, '-a', context)):
         return verifyRasterNum(alg, parameters, context, 'input', 6)
-    return None
+    return True, None
