@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
 
 
 from processing.tools.system import getTempFilename
@@ -33,9 +33,9 @@ def checkParameterValuesBeforeExecuting(alg, parameters, context):
     """ Verify if we have the right parameters """
     if (alg.parameterAsString(parameters, 'rules', context)
             and alg.parameterAsString(parameters, 'txtrules', context)):
-        return alg.tr("You need to set either a rules file or write directly the rules!")
+        return False, alg.tr("You need to set either a rules file or write directly the rules!")
 
-    return None
+    return True, None
 
 
 def processCommand(alg, parameters, context, feedback):
