@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive323
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
 
 import math
 from processing.algs.qgis.QgisAlgorithm import QgisAlgorithm
@@ -77,6 +77,9 @@ class ExtractSpecificVertices(QgisAlgorithm):
 
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT, context)
+        if source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+
         fields = source.fields()
         fields.append(QgsField('vertex_pos', QVariant.Int))
         fields.append(QgsField('vertex_index', QVariant.Int))
@@ -95,6 +98,8 @@ class ExtractSpecificVertices(QgisAlgorithm):
 
         (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
                                                fields, wkb_type, source.sourceCrs())
+        if sink is None:
+            raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
         vertex_indices_string = self.parameterAsString(parameters, self.VERTICES, context)
         indices = []
