@@ -23,25 +23,39 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
 
 import os
+import warnings
+
+from qgis.gui import QgsGui
 
 from qgis.PyQt import uic
 from qgis.PyQt.QtWidgets import QDialog, QPushButton, QAbstractItemView, QDialogButtonBox
 from qgis.PyQt.QtGui import QStandardItemModel, QStandardItem
 
 pluginPath = os.path.split(os.path.dirname(__file__))[0]
-WIDGET, BASE = uic.loadUiType(
-    os.path.join(pluginPath, 'ui', 'DlgFixedTable.ui'))
+
+with warnings.catch_warnings():
+    warnings.filterwarnings("ignore", category=DeprecationWarning)
+    WIDGET, BASE = uic.loadUiType(
+        os.path.join(pluginPath, 'ui', 'DlgFixedTable.ui'))
 
 
 class FixedTableDialog(BASE, WIDGET):
 
     def __init__(self, param, table):
-        super(FixedTableDialog, self).__init__(None)
+        """
+        Constructor for FixedTableDialog
+        :param param: linked processing parameter
+        :param table: initial table contents - squashed to 1-dimensional!
+        """
+        super().__init__(None)
+
         self.setupUi(self)
 
+        QgsGui.instance().enableAutoGeometryRestore(self)
+
         self.tblView.setSelectionBehavior(QAbstractItemView.SelectRows)
         self.tblView.setSelectionMode(QAbstractItemView.ExtendedSelection)
 
@@ -72,27 +86,27 @@ class FixedTableDialog(BASE, WIDGET):
 
     def populateTable(self, table):
         cols = len(self.param.headers())
-        rows = len(table)
+        rows = len(table) // cols
         model = QStandardItemModel(rows, cols)
 
         # Set headers
         model.setHorizontalHeaderLabels(self.param.headers())
 
         # Populate table
-        for i in range(rows):
-            for j in range(cols):
-                item = QStandardItem(str(table[i][j]))
-                model.setItem(i, j, item)
+        for row in range(rows):
+            for col in range(cols):
+                item = QStandardItem(str(table[row * cols + col]))
+                model.setItem(row, col, item)
         self.tblView.setModel(model)
 
     def accept(self):
         cols = self.tblView.model().columnCount()
         rows = self.tblView.model().rowCount()
+        # Table MUST BE 1-dimensional to match core QgsProcessingParameterMatrix expectations
         self.rettable = []
-        for i in range(rows):
-            self.rettable.append(list())
-            for j in range(cols):
-                self.rettable[i].append(str(self.tblView.model().item(i, j).text()))
+        for row in range(rows):
+            for col in range(cols):
+                self.rettable.append(str(self.tblView.model().item(row, col).text()))
         QDialog.accept(self)
 
     def reject(self):
