@@ -23,9 +23,10 @@ __copyright__ = '(C) 2016, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
 
 import os
+import warnings
 
 from qgis.core import (QgsProject,
                        QgsReferencedPointXY,
@@ -37,8 +38,11 @@ from qgis.utils import iface
 from processing.gui.PointMapTool import PointMapTool
 
 pluginPath = os.path.split(os.path.dirname(__file__))[0]
-WIDGET, BASE = uic.loadUiType(
-    os.path.join(pluginPath, 'ui', 'widgetBaseSelector.ui'))
+
+with warnings.catch_warnings():
+    warnings.filterwarnings("ignore", category=DeprecationWarning)
+    WIDGET, BASE = uic.loadUiType(
+        os.path.join(pluginPath, 'ui', 'widgetBaseSelector.ui'))
 
 
 class PointSelectionPanel(BASE, WIDGET):
